package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Enterprises;
import com.ruoyi.system.service.IEnterprisesService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

import static com.ruoyi.common.utils.PageUtils.startPage;

@RestController
@RequestMapping("/app/enterprise")
@Slf4j
public class EnterpriseController extends BaseController{

	@Autowired
	private IEnterprisesService enterprisesService;

	/**
	 * 查询企业列表
	 */
	@PreAuthorize("@ss.hasPermi('system:enterprises:list')")
	@GetMapping("/list")
	public TableDataInfo list(Enterprises enterprises)
	{
		startPage();
		List<Enterprises> list = enterprisesService.selectAppEnterprisesList(enterprises);
		return getDataTable(list);
	}

	/**
	 * 导出企业列表
	 */
	@PreAuthorize("@ss.hasPermi('system:enterprises:export')")
	@Log(title = "企业", businessType = BusinessType.EXPORT)
	@PostMapping("/export")
	public void export(HttpServletResponse response, Enterprises enterprises)
	{
		List<Enterprises> list = enterprisesService.selectEnterprisesList(enterprises);
		ExcelUtil<Enterprises> util = new ExcelUtil<Enterprises>(Enterprises.class);
		util.exportExcel(response, list, "企业数据");
	}

	/**
	 * 获取企业详细信息
	 */
	@PreAuthorize("@ss.hasPermi('system:enterprises:query')")
	@GetMapping(value = "/{id}")
	public AjaxResult getInfo(@PathVariable("id") Long id)
	{
		return success(enterprisesService.selectEnterprisesById(id));
	}

//	public AjaxResult getEnterprisesByUserId(Long userId) {
//
//	}

	/**
	 * 新增企业
	 */
	@PreAuthorize("@ss.hasPermi('system:enterprises:add')")
	@Log(title = "企业", businessType = BusinessType.INSERT)
	@PostMapping
	public AjaxResult add(@RequestBody Enterprises enterprises)
	{
		return toAjax(enterprisesService.insertEnterprises(enterprises));
	}

	/**
	 * 修改企业
	 */
	@PreAuthorize("@ss.hasPermi('system:enterprises:edit')")
	@Log(title = "企业", businessType = BusinessType.UPDATE)
	@PutMapping
	public AjaxResult edit(@RequestBody Enterprises enterprises)
	{
		log.info("enterprisesenterprises:{}", enterprises);
		return toAjax(enterprisesService.updateEnterprises(enterprises));
	}

	/**
	 * 删除企业
	 */
	@PreAuthorize("@ss.hasPermi('system:enterprises:remove')")
	@Log(title = "企业", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
	public AjaxResult remove(@PathVariable List<Long> ids)
	{
		return toAjax(enterprisesService.deleteEnterprisesByIds(ids));
	}

}
