package com.ruoyi.web.controller.common;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.FileInfo;
import com.ruoyi.system.service.IFileInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 附件信息Controller
 *
 * @author ruoyi
 * @date 2025-01-16
 */
@RestController
@RequestMapping("/system/fileInfo")
public class FileInfoController extends BaseController
{
    @Autowired
    private IFileInfoService fileInfoService;

    /**
     * 查询附件信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:fileInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(FileInfo fileInfo)
    {
        startPage();
        List<FileInfo> list = fileInfoService.list(new QueryWrapper<FileInfo>());
        return getDataTable(list);
    }

//    /**
//     * 导出附件信息列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:fileInfo:export')")
//    @Log(title = "附件信息", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, FileInfo fileInfo)
//    {
//        List<FileInfo> list = fileInfoService.selectFileInfoList(fileInfo);
//        ExcelUtil<FileInfo> util = new ExcelUtil<FileInfo>(FileInfo.class);
//        util.exportExcel(response, list, "附件信息数据");
//    }

    /**
     * 获取附件信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fileInfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fileInfoService.getById(id));
    }

    /**
     * 新增附件信息
     */
    @PreAuthorize("@ss.hasPermi('system:fileInfo:add')")
    @Log(title = "附件信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FileInfo fileInfo)
    {
        return toAjax(fileInfoService.save(fileInfo));
    }

    /**
     * 修改附件信息
     */
    @PreAuthorize("@ss.hasPermi('system:fileInfo:edit')")
    @Log(title = "附件信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FileInfo fileInfo)
    {
        return toAjax(fileInfoService.updateById(fileInfo));
    }

    /**
     * 删除附件信息
     */
    @PreAuthorize("@ss.hasPermi('system:fileInfo:remove')")
    @Log(title = "附件信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        return toAjax(fileInfoService.removeByIds(ids));
    }
}
