package com.ruoyi.web.controller.common;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.MinioUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/common_file")
public class MinioController {

	@Autowired
	private MinioUtils minioUtils;

	/**
	 * 上传文件
	 */
	@PostMapping("/upload")
	public AjaxResult uploadFile(@RequestParam("file") MultipartFile file) {
		String objectName = "uploads/" + System.currentTimeMillis() + "_" + file.getOriginalFilename();
		try (InputStream inputStream = file.getInputStream()) {
			minioUtils.uploadFile( objectName, inputStream, file.getSize(), file.getContentType());
		} catch (Exception e) {
			throw new RuntimeException("文件上传失败", e);
		}
		final String url = minioUtils.generateShortUrl(objectName);
		return AjaxResult.success("上传成功", url);
	}

	@PostMapping("/uploads")
	public AjaxResult uploadMultipleFiles(@RequestParam("files") List<MultipartFile> files) {
		List<String> uploadedUrls = new ArrayList<>();
		for (MultipartFile file : files) {
			String objectName = "uploads/" + System.currentTimeMillis() + "_" + file.getOriginalFilename();

			try (InputStream inputStream = file.getInputStream()) {
				minioUtils.uploadFile(objectName, inputStream, file.getSize(), file.getContentType());
				String shortUrl = minioUtils.generateShortUrl(objectName);
				uploadedUrls.add(shortUrl);
			} catch (Exception e) {
				throw new RuntimeException("文件上传失败: " + file.getOriginalFilename(), e);
			}
		}

		return AjaxResult.success("上传成功", uploadedUrls);
	}


	/**
	 * 下载文件
	 */
	@GetMapping("/download")
	public ResponseEntity<byte[]> downloadFile(@RequestParam("fileName") String fileName) {
		try {
			InputStream inputStream = minioUtils.downloadFile(fileName);
			return ResponseEntity.ok(inputStream.readAllBytes());
		} catch (Exception e) {
			return ResponseEntity.badRequest().body(e.getMessage().getBytes());
		}
	}

	/**
	 * 获取存储桶中的文件列表
	 */
	@GetMapping("/listBuckets")
	public ResponseEntity<?> listBuckets() {
		return ResponseEntity.ok(minioUtils.listBuckets());
	}
}
