package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.common.core.domain.entity.SysDictType;
import com.ruoyi.common.core.page.PageParam;
import com.ruoyi.system.domain.dto.TaskPageDto;
import com.ruoyi.system.domain.vo.TaskInsertEnterprisesVo;
import com.ruoyi.system.domain.vo.TaskPageVo;
import com.ruoyi.system.domain.vo.TaskSaveVo;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Tasks;
import com.ruoyi.system.service.ITasksService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务，用于存储所有的任务信息，任务可由不同用户创建并管理。Controller
 *
 * @author ruoyi
 * @date 2025-01-14
 */
@RestController
@RequestMapping("/system/tasks")
public class TasksController extends BaseController
{
    @Autowired
    private ITasksService tasksService;

    /**
     * 查询任务，用于存储所有的任务信息，任务可由不同用户创建并管理。列表
     */
    @PreAuthorize("@ss.hasPermi('system:tasks:list')")
    @GetMapping("/list")
    public TableDataInfo list(Tasks tasks)
    {
        startPage();
        List<TaskPageDto> list = tasksService.getPage();
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('system:tasks:list')")
    @PostMapping("/insertEnterprises")
    public AjaxResult taskInsertEnterprises(@RequestBody TaskInsertEnterprisesVo taskInsertEnterprisesVo){
    	tasksService.taskInsertEnterprises(taskInsertEnterprisesVo);
    	return AjaxResult.success("保存成功");
    }


    /**
     * 导出任务，用于存储所有的任务信息，任务可由不同用户创建并管理。列表
     */
//    @PreAuthorize("@ss.hasPermi('system:tasks:export')")
//    @Log(title = "任务，用于存储所有的任务信息，任务可由不同用户创建并管理。", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, Tasks tasks)
//    {
//        List<Tasks> list = tasksService.(tasks);
//        ExcelUtil<Tasks> util = new ExcelUtil<Tasks>(Tasks.class);
//        util.exportExcel(response, list, "任务，用于存储所有的任务信息，任务可由不同用户创建并管理。数据");
//    }

    /**
     * 获取任务，用于存储所有的任务信息，任务可由不同用户创建并管理。详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:tasks:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tasksService.getOptById(id));
    }

    /**
     * 新增任务，用于存储所有的任务信息，任务可由不同用户创建并管理。
     */
    @PreAuthorize("@ss.hasPermi('system:tasks:add')")
    @Log(title = "任务，用于存储所有的任务信息，任务可由不同用户创建并管理。", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TaskSaveVo taskSaveVo)
    {
        tasksService.insertTasks(taskSaveVo);
        return success("添加任务成功");
    }

    /**
     * 修改任务，用于存储所有的任务信息，任务可由不同用户创建并管理。
     */
    @PreAuthorize("@ss.hasPermi('system:tasks:edit')")
    @Log(title = "任务，用于存储所有的任务信息，任务可由不同用户创建并管理。", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Tasks tasks)
    {
        return toAjax(tasksService.updateById(tasks));
    }

    /**
     * 删除任务，用于存储所有的任务信息，任务可由不同用户创建并管理。
     */
    @PreAuthorize("@ss.hasPermi('system:tasks:remove')")
    @Log(title = "任务，用于存储所有的任务信息，任务可由不同用户创建并管理。", businessType = BusinessType.DELETE)
	@DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Long id)
    {
        return toAjax(tasksService.removeById(id));
    }
}
