package com.ruoyi.common.utils;

import com.baomidou.mybatisplus.annotation.TableName;
import com.ruoyi.common.annotation.PrimaryKey;

import java.lang.reflect.Field;

public class EntityUtils {

	/**
	 * 获取实体类的主键值
	 *
	 * @param entity 实体对象
	 * @return 主键值
	 */
	public static Long getPrimaryKeyValue(Object entity) {
		for (Field field : entity.getClass().getDeclaredFields()) {
			if (field.isAnnotationPresent(PrimaryKey.class)) {
				field.setAccessible(true);
				try {
					return (Long) field.get(entity); // 假设主键类型为 Long
				} catch (IllegalAccessException e) {
					throw new RuntimeException("无法访问主键字段的值", e);
				}
			}
		}
		throw new RuntimeException("实体类中未找到 @PrimaryKey 标记的字段");
	}

	/**
	 * 获取实体类对应的表名
	 *
	 * @param entity 实体对象
	 * @return 表名
	 */
	public static String getTableName(Object entity) {
		TableName tableNameAnnotation = entity.getClass().getAnnotation(TableName.class);
		return tableNameAnnotation != null ? tableNameAnnotation.value() : entity.getClass().getSimpleName();
	}


	/**
	 * 判断实体类是否包含 @PrimaryKey 注解的字段
	 *
	 * @param entity 实体对象
	 * @return 是否包含主键注解
	 */
	public static boolean hasPrimaryKeyAnnotation(Object entity) {
		for (Field field : entity.getClass().getDeclaredFields()) {
			if (field.isAnnotationPresent(PrimaryKey.class)) {
				return true; // 找到带有 @PrimaryKey 的字段
			}
		}
		return false; // 未找到
	}
}

