package com.ruoyi.common.utils;

import io.minio.*;
import io.minio.http.Method;
import io.minio.messages.Bucket;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import java.io.InputStream;
import java.util.List;

@Component
public class MinioUtils {

	@Autowired
	private MinioClient minioClient;

	@Value("${minio.bucketName}")
	private String bucketName;

	@Value("${minio.endpoint}")
	private String endpoint;

	/**
	 * 上传文件
	 */
	public void uploadFile(String objectName, InputStream fileInputStream, long size, String contentType) throws Exception {
		minioClient.putObject(
				PutObjectArgs.builder()
						.bucket(bucketName)
						.object(objectName)
						.stream(fileInputStream, size, -1)
						.contentType(contentType)
						.build()
		);
	}

	public String generateShortUrl(String objectName) {
		// 返回自定义短链接地址
		return endpoint + "/" +bucketName + "/" + objectName;
	}

	public String generatePresignedUrl(String objectName) {
		try {
			return minioClient.getPresignedObjectUrl(
					GetPresignedObjectUrlArgs.builder()
							.bucket(bucketName)
							.object(objectName)
							.expiry(3600) // 有效期1小时
							.build()
			);
		} catch (Exception e) {
			throw new RuntimeException("Failed to generate presigned URL", e);
		}
	}


	/**
	 * 下载文件
	 */
	public InputStream downloadFile(String objectName) {
		try {
			return minioClient.getObject(
					GetObjectArgs.builder()
							.bucket(bucketName)
							.object(objectName)
							.build()
			);
		} catch (Exception e) {
			throw new RuntimeException("文件下载失败：" + e.getMessage());
		}
	}

	/**
	 * 列出存储桶中的所有文件
	 */
	public List<Bucket> listBuckets() {
		try {
			return minioClient.listBuckets();
		} catch (Exception e) {
			throw new RuntimeException("获取存储桶列表失败：" + e.getMessage());
		}
	}
}

