package com.ruoyi.common.utils;

import org.quartz.*;
import org.springframework.stereotype.Component;

/**
 * 定时任务工具类，支持创建和删除任务
 */
@Component
public class ScheduleUtils {

	/**
	 * 创建定时任务
	 *
	 * @param scheduler       Quartz调度器
	 * @param jobName         任务名称
	 * @param groupName       任务分组
	 * @param cronExpression  Cron表达式
	 * @param jobDetail       任务详情
	 */
	public static void createJob(Scheduler scheduler, String jobName, String groupName, String cronExpression, JobDetail jobDetail) throws SchedulerException {
		CronScheduleBuilder cronScheduleBuilder = CronScheduleBuilder.cronSchedule(cronExpression);
		CronTrigger trigger = TriggerBuilder.newTrigger()
				.withIdentity(jobName, groupName)
				.withSchedule(cronScheduleBuilder)
				.build();
		scheduler.scheduleJob(jobDetail, trigger);
	}

	/**
	 * 删除定时任务
	 *
	 * @param scheduler Quartz调度器
	 * @param jobName   任务名称
	 * @param groupName 任务分组
	 */
	public static void deleteJob(Scheduler scheduler, String jobName, String groupName) throws SchedulerException {
		JobKey jobKey = JobKey.jobKey(jobName, groupName);
		scheduler.deleteJob(jobKey);
	}
}
