package com.ruoyi.framework.aspectj;

import com.ruoyi.common.utils.EntityUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.SysFieldChangeLog;
import com.ruoyi.system.service.CommonService;
import com.ruoyi.system.service.SysFieldChangeLogService;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.Map;
@Aspect
@Component
public class LogDeleteOperation {

	@Autowired
	private CommonService commonService;

	@Autowired
	private SysFieldChangeLogService fieldChangeLogService;

	@Around("execution(* com.ruoyi.*.service.*.delete*(..))")
	public Object logDeleteOperation(ProceedingJoinPoint point) throws Throwable {
		Object[] args = point.getArgs();
		if (args.length == 0) {
			return point.proceed();
		}

		Object entityToDelete = args[0];

		// 判断是否包含 @PrimaryKey 注解
		if (!EntityUtils.hasPrimaryKeyAnnotation(entityToDelete)) {
			return point.proceed(); // 如果没有主键注解，跳过日志记录
		}


		// 使用工具类获取主键值和表名
		Long recordId = EntityUtils.getPrimaryKeyValue(entityToDelete);
		String tableName = EntityUtils.getTableName(entityToDelete	);

		// 动态查询记录
		Map<String, Object> originalRecord = commonService.findById(tableName, recordId);

		// 保存删除日志
		saveDeleteLogs(originalRecord, tableName, recordId);

		return point.proceed();
	}

	private void saveDeleteLogs(Map<String, Object> original, String tableName, Long recordId) {
		Long userId = SecurityUtils.getLoginUser().getUserId();
		String username = SecurityUtils.getLoginUser().getUsername();

		for (Map.Entry<String, Object> entry : original.entrySet()) {
			SysFieldChangeLog log = new SysFieldChangeLog();
			log.setTableName(tableName);
			log.setRecordId(recordId);
			log.setFieldName(entry.getKey());
			log.setOldValue(entry.getValue() != null ? entry.getValue().toString() : null);
			log.setNewValue(null); // 删除操作，新值为空
			log.setUserId(userId);
			log.setUsername(username);
			log.setOperationType("删除");
			log.setCreateTime(new Date());
			fieldChangeLogService.save(log);
		}
	}

}
