package com.ruoyi.framework.mybatis.handler;

import com.baomidou.mybatisplus.core.handlers.MetaObjectHandler;
import com.ruoyi.common.utils.SecurityUtils;
import org.apache.ibatis.reflection.MetaObject;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * 自定义元对象处理器，用于自动填充创建和修改时间、用户
 */
@Component
public class CustomMetaObjectHandler implements MetaObjectHandler {

	@Override
	public void insertFill(MetaObject metaObject) {
		// 创建时自动填充
		this.strictInsertFill(metaObject, "createTime", Date.class, new Date());
		this.strictInsertFill(metaObject, "createBy", String.class, getCurrentUsername());
		this.strictInsertFill(metaObject, "updateTime", Date.class, new Date());
		this.strictInsertFill(metaObject, "updateBy", String.class, getCurrentUsername());
	}

	@Override
	public void updateFill(MetaObject metaObject) {
		// 修改时自动填充
		this.strictUpdateFill(metaObject, "updateTime", Date.class, new Date());
		this.strictUpdateFill(metaObject, "updateBy", String.class, getCurrentUsername());
	}

	/**
	 * 获取当前登录用户名
	 */
	private String getCurrentUsername() {
		try {
			return SecurityUtils.getUsername();
		} catch (Exception e) {
			return "unknown";
		}
	}
}
