package com.ruoyi.framework.utils;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.config.WeChatConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;

@Component
@Slf4j
public class WeChatUtils {

	@Autowired
	private WeChatConfig weChatConfig;

	private final RestTemplate restTemplate = new RestTemplate();

	//获取openid
	public JSONObject getSession(String code) {
		String appId = weChatConfig.getAppId();
		String appSecret = weChatConfig.getAppSecret();
		String url = String.format(
				"https://api.weixin.qq.com/sns/jscode2session?appid=%s&secret=%s&js_code=%s&grant_type=authorization_code",
				appId, appSecret, code
		);
		String response = restTemplate.getForObject(url, String.class);

		log.info("response: {}", response);

		return JSONObject.parseObject(response);
	}

	/**
	 * 获取微信用户信息
	 *
	 * @param accessToken 有效的 access_token
	 * @param openid      用户的 openid
	 * @return 用户信息 JSON 对象
	 */
	public JSONObject getUserInfo(String accessToken, String openid) {
		String url = String.format(
				"https://api.weixin.qq.com/sns/userinfo?access_token=%s&openid=%s",
				accessToken, openid
		);

		try {
			// 调用微信接口获取用户信息
			String response = restTemplate.getForObject(url, String.class);
			JSONObject userInfo = JSONObject.parseObject(response);

			// 判断接口返回是否成功
			if (userInfo.containsKey("errcode")) {
				log.error("Failed to get user info: {}", userInfo.getString("errmsg"));
				throw new RuntimeException("Failed to get user info from WeChat API");
			}

			return userInfo;
		} catch (Exception e) {
			log.error("Error getting user info from WeChat", e);
			throw new RuntimeException("Error getting user info from WeChat");
		}
	}

	/**
	 * 构建微信扫码登录的二维码 URL
	 */
	public String getQRCodeUrl(String state) {

		String appId = weChatConfig.getAppId();
		String callBackUrl = weChatConfig.getCallBackUrl();
		return String.format(
				"https://open.weixin.qq.com/connect/qrconnect?appid=%s&redirect_uri=%s&response_type=code&scope=snsapi_login&state=%s",
				appId, callBackUrl, state
		);
	}

	//

}
