package com.ruoyi.system.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.EnterpriseQualification;
import com.ruoyi.system.domain.EnterpriseUsers;
import com.ruoyi.system.domain.vo.EnterpriseUserInsertVo;
import com.ruoyi.system.domain.vo.LabelValueVo;
import com.ruoyi.system.mapper.EnterpriseUsersMapper;
import com.ruoyi.system.mapper.EnterprisesQualificationMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.EnterprisesMapper;
import com.ruoyi.system.domain.Enterprises;
import com.ruoyi.system.service.IEnterprisesService;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestBody;

/**
 * 企业Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-08
 */
@Service
@Slf4j

public class EnterprisesServiceImpl extends ServiceImpl<EnterprisesMapper, Enterprises> implements IEnterprisesService
{
    @Autowired
    private EnterprisesMapper enterprisesMapper;
    @Autowired
    private EnterpriseUsersMapper enterpriseUsersMapper;
    @Autowired
    private IEnterprisesService iEnterprisesService;

    /**
     * 查询企业
     *
     * @param id 企业主键
     * @return 企业
     */
    @Override
    public Enterprises selectEnterprisesById(Long id)
    {
        return enterprisesMapper.selectEnterprisesById(id);
    }

    /**
     * 查询企业列表
     *
     * @param enterprises 企业
     * @return 企业
     */
    @Override
    public List<Enterprises> selectEnterprisesList(Enterprises enterprises)
    {
        QueryWrapper<Enterprises> wrapper = new QueryWrapper<>();
        wrapper.eq("del_flag", "0");
        return enterprisesMapper.selectList(wrapper);
    }

    /**
     * 新增企业
     *
     * @param enterprises 企业
     * @return 结果
     */
    @Override
    public int insertEnterprises(Enterprises enterprises)
    {
        return enterprisesMapper.insert(enterprises);
    }

    /**
     * 修改企业
     *
     * @param enterprises 企业
     * @return 结果
     */
    @Override
    public int updateEnterprises(@RequestBody Enterprises enterprises)
    {
        final Enterprises enterprises1 = enterprisesMapper.selectById(enterprises.getId());
        if (enterprises == null) {
            throw new ServiceException("企业信息不存在");
        }
        BeanUtils.copyProperties(enterprises, enterprises1);
        return enterprisesMapper.updateById(enterprises1);
    }

    /**
     * 批量删除企业
     *
     * @param ids 需要删除的企业主键
     * @return 结果
     */
    @Override
    public int deleteEnterprisesByIds(List<Long> ids)
    {
        return enterprisesMapper.deleteByIds(ids);
    }

    /**
     * 删除企业信息
     *
     * @param id 企业主键
     * @return 结果
     */
    @Override
    public int deleteEnterprisesById(Long id)
    {
        return enterprisesMapper.deleteEnterprisesById(id);
    }

    @Override
    @Transactional
    public void addEnterpriseUsers(EnterpriseUserInsertVo enterpriseUserInsertVo) {

        final Enterprises enterprises = enterprisesMapper.selectById(enterpriseUserInsertVo.getEnterpriseId());
        if (enterprises == null) {
            throw new ServiceException("企业不存在");
        }
        List<Long> userId = enterpriseUserInsertVo.getUserId();
        if (userId.size() < 1) {
            throw new ServiceException("请选择用户");
        }

        userId.forEach(id -> {
            EnterpriseUsers enterpriseUsers = new EnterpriseUsers();
            enterpriseUsers.setUserId(id);
            enterpriseUsers.setEnterpriseId(enterpriseUserInsertVo.getEnterpriseId());
            enterpriseUsersMapper.insert(enterpriseUsers);
        });
    }

    @Override
    public List<LabelValueVo> simpleList(Enterprises enterprises) {
        LambdaQueryWrapper<Enterprises> wrapper = new LambdaQueryWrapper<>();
        wrapper.select(Enterprises::getId, Enterprises::getEnterprisesName);

        final List<Enterprises> enterprisesList = enterprisesMapper.selectList(wrapper);

        List<LabelValueVo> labelValueVo = new ArrayList<>();
        enterprisesList.forEach(item->{
            LabelValueVo res = new LabelValueVo();
            res.setLabel(item.getEnterprisesName());
            res.setValue(item.getId());
            labelValueVo.add(res);
        });

        return labelValueVo;
    }

    @Override
    public List<Enterprises> selectAppEnterprisesList(Enterprises enterprises) {
        //根据角色和部门等级查询相关企业
        return null;
    }
}
