package com.ruoyi.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.EnterpriseInspections;
import com.ruoyi.system.domain.TaskEnterprises;
import com.ruoyi.system.domain.dto.TaskPageDto;
import com.ruoyi.system.domain.vo.TaskAppSelectVo;
import com.ruoyi.system.domain.vo.TaskInsertEnterprisesVo;
import com.ruoyi.system.domain.vo.TaskSaveVo;
import com.ruoyi.system.mapper.EnterpriseInspectionsMapper;
import com.ruoyi.system.mapper.TaskEnterprisesMapper;
import com.ruoyi.system.service.IEnterpriseInspectionsService;
import com.ruoyi.system.service.ITaskAssignmentsService;
import com.ruoyi.system.service.ITaskEnterprisesService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TasksMapper;
import com.ruoyi.system.domain.Tasks;
import com.ruoyi.system.service.ITasksService;
import com.ruoyi.system.mapper.TasksMapper;
import org.springframework.transaction.annotation.Transactional;
import reactor.core.scheduler.Scheduler;

import java.util.ArrayList;
import java.util.List;
//import org.quartz.Scheduler;

/**
 * 任务，用于存储所有的任务信息，任务可由不同用户创建并管理。Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-14
 */
@Service
public class TasksServiceImpl extends ServiceImpl<TasksMapper, Tasks> implements ITasksService {

	@Autowired
	private TaskEnterprisesMapper taskEnterprisesMapper;
	@Autowired
	private ITaskAssignmentsService iTaskAssignmentsService;
	@Autowired
	private ITaskEnterprisesService iTaskEnterprisesService;

	@Autowired
	private IEnterpriseInspectionsService iEnterpriseInspectionsService;

	@Autowired
	private TasksMapper tasksMapper;


	@Override
	public void insertTasks(TaskSaveVo taskSaveVo) {
		//任务类型
		Tasks tasks = new Tasks();
		BeanUtils.copyProperties(taskSaveVo, tasks);
		final int insert = tasksMapper.insert(tasks);
		if (insert < 1) {
			throw new ServiceException("插入失败");
		}

//		if (taskSaveVo.getTaskType() == 2) {
//			//自动执行
//
//
//		} else {
//
//		}
//
//		final List<Long> enterprisesList = taskSaveVo.getEnterprisesList();
//		for (Long id : enterprisesList) {
//			TaskEnterprises enterprises = new TaskEnterprises();
//			enterprises.setTaskId(tasks.getId());
//			enterprises.setEnterpriseId(id);
//			taskEnterprisesMapper.insert(enterprises);
//		}
//
//		return 0;
	}
	@Transactional
	public void taskInsertEnterprises(TaskInsertEnterprisesVo taskInsertEnterprisesVo) {

		final List<Long> enterprisesList = taskInsertEnterprisesVo.getEnterprisesList();

		if (enterprisesList.size() < 1) {
			throw new ServiceException("任务不能为空");
		}
		final Tasks tasks = tasksMapper.selectById(taskInsertEnterprisesVo.getTaskId());
		if (tasks == null) {
			throw new ServiceException("任务不存在");
		}

		for (Long id : enterprisesList) {
			TaskEnterprises enterprises = new TaskEnterprises();
			enterprises.setTaskId(tasks.getId());
			enterprises.setEnterpriseId(id);
			final int insert = taskEnterprisesMapper.insert(enterprises);
			if (insert < 1) {
				throw new ServiceException("插入失败");
			}
		}
	}

	@Override
	public List<TaskAppSelectVo> getAppTaskList() {
		final Long userId = SecurityUtils.getUserId();

		QueryWrapper<TaskEnterprises> wrapper = new QueryWrapper<>();
		wrapper.apply("FIND_IN_SET({0}, user_id)", userId);
		wrapper.groupBy("task_id");
		wrapper.select("task_id", "COUNT(enterprise_id) AS count");
		final List<TaskEnterprises> taskEnterprisesList = taskEnterprisesMapper.selectList(wrapper);

		List<TaskAppSelectVo> list = new ArrayList<>();

		if (taskEnterprisesList.size() > 0) {
			taskEnterprisesList.forEach(item -> {
				TaskAppSelectVo taskAppSelectVo = new TaskAppSelectVo();
				list.add(taskAppSelectVo);
				final Tasks tasks = tasksMapper.selectById(item.getTaskId());
				if (tasks == null) {
					throw new ServiceException("任务不存在");
				}
				taskAppSelectVo.setTaskName(tasks.getTitle());
				taskAppSelectVo.setDescription(tasks.getDescription());
			});
		}


		return list;
	}

	@Override
	public List<TaskPageDto> getPage() {

		List<TaskPageDto> list = new ArrayList<>();

		QueryWrapper<Tasks> wrapper = new QueryWrapper<>();
		wrapper.eq("del_flag", 0);
		final List<Tasks> tasks = tasksMapper.selectList(wrapper);
		if (tasks.size() > 0) {
			tasks.forEach(item->{
				TaskPageDto taskPageDto = new TaskPageDto();
				taskPageDto.setTitle(item.getTitle());
				taskPageDto.setType(item.getTaskType());
				taskPageDto.setExecCycle(item.getExecCycle());
				LambdaQueryWrapper<TaskEnterprises> taskEnterprisesLambdaQueryWrapper = new LambdaQueryWrapper<>();
				taskEnterprisesLambdaQueryWrapper.eq(item.getId() != null, TaskEnterprises::getTaskId, item.getId());
				final long count = iTaskEnterprisesService.count();
				taskPageDto.setScope((int) count);
				LambdaQueryWrapper<EnterpriseInspections> queryWrapper = new LambdaQueryWrapper<>();
				queryWrapper.eq(EnterpriseInspections::getStatus, 1);
				queryWrapper.eq(item.getId() != null, EnterpriseInspections::getTaskId, item.getId());
				final long count1 = iEnterpriseInspectionsService.count();
				taskPageDto.setCompletionProgress(count1+"/"+count);
				list.add(taskPageDto);
			});
		}

		return list;
	}
}
